package com.webchat.rmi.pay;

import com.webchat.common.bean.APIResponseBean;
import com.webchat.domain.dto.payment.PaymentTransRequestDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestHeader;

import java.math.BigDecimal;

@FeignClient(name = "webchat-pay-service", contextId = "paymentApiServiceClient")
public interface PaymentApiServiceClient {

    /**
     * 获取交易接入方凭证
     *
     * @param accessKey
     * @param sign 签名
     * @return
     */
    @GetMapping("/pay-service/api/token")
    APIResponseBean<String> accessToken(@RequestHeader(name = "app-id") Long appId,
                                  @RequestHeader(name = "access-key") String accessKey,
                                  @RequestHeader(name = "secret-key") String secretKey,
                                  @RequestHeader Long timestamp,
                                  @RequestHeader String signature,
                                  @RequestHeader(name = "log-id") String logId);

    /**
     * 获取交易事务id（用于交易回滚，分布式事务一致性）
     *
     * @param token
     * @return
     */
    @GetMapping("/pay-service/api/transId")
    APIResponseBean<String> transId(@RequestHeader String token,
                                    @RequestHeader String logId);

    /**
     * 真实交易接口
     *
     * @return
     */
    @PostMapping("/pay-service/api/doTrans")
    APIResponseBean<Boolean> doTrans(@RequestBody PaymentTransRequestDTO paymentTransRequest,
                                     @RequestHeader String token,
                                     @RequestHeader String transId,
                                     @RequestHeader String logId);


    /**
     * 交易回滚（保证分布式事务数据一致性）
     *
     * @param token
     * @param transId
     * @param logId
     * @return
     */
    @PostMapping("/pay-service/api/rollback")
    APIResponseBean<Boolean> rollback(@RequestHeader String token,
                                      @RequestHeader String transId,
                                      @RequestHeader String logId);

    /**
     * 查询账户余额
     *
     * @param userId
     * @return
     */
    @GetMapping("/pay-service/api/balance/{userId}")
    APIResponseBean<BigDecimal> balance(@PathVariable String userId,
                                        @RequestHeader String token,
                                        @RequestHeader String logId);
}
